==> flutter_bucketeer-1.0.0.tar.gz: android/src/main/java/jp/bucketeer/plugin/BucketeerPlugin.java <==
package jp.bucketeer.plugin;

import android.content.Context;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import java.util.HashMap;
import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import jp.bucketeer.sdk.Bucketeer;
import jp.bucketeer.sdk.BucketeerConfig;
import jp.bucketeer.sdk.BucketeerException;

/**
 * BucketeerPlugin
 */
public class BucketeerPlugin implements MethodCallHandler, FlutterPlugin {
  private Context applicationContext;
  private MethodChannel methodChannel;
  private Bucketeer bucketeer;
  private Result result;

  /**
   * Plugin registration.
   */
  public static void registerWith(Registrar registrar) {
    final BucketeerPlugin instance = new BucketeerPlugin();
    instance.onAttachedToEngine(registrar.context(), registrar.messenger());
  }

  @Override
  public void onAttachedToEngine(FlutterPluginBinding binding) {
    onAttachedToEngine(binding.getApplicationContext(), binding.getBinaryMessenger());
  }

  private void onAttachedToEngine(Context applicationContext, BinaryMessenger messenger) {
    this.applicationContext = applicationContext;
    methodChannel = new MethodChannel(messenger, "jp.bucketeer.plugin/flutter");
    methodChannel.setMethodCallHandler(this);
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    applicationContext = null;
    methodChannel.setMethodCallHandler(null);
    methodChannel = null;
  }

  @Override
  public void onMethodCall(final MethodCall call, @NonNull final Result result) {
    this.result = result;
    try {
      switch (call.method) {
        case "initialize": {
          final BucketeerConfig config = new BucketeerConfig.Builder()
            .logSendingIntervalMillis(safeCast(call.argument("logSendingIntervalMillis"), Integer.class))
            .logSendingMaxBatchQueueCount(safeCast(call.argument("logSendingMaxBatchQueueCount"), Integer.class))
            .pollingEvaluationIntervalMillis(safeCast(call.argument("pollingEvaluationIntervalMillis"), Integer.class))
            .build();

          bucketeer = new Bucketeer.Builder(applicationContext)
            .config(config)
            .apiKey(safeCast(call.argument("apiKey"), String.class))
            .endpoint(safeCast(call.argument("endpoint"), String.class))
            .featureTag(safeCast(call.argument("featureTag"), String.class))
            .logcatLogging(safeCast(call.argument("debugging"), Boolean.class))
            .build();
          success();
          break;
        }
        case "setUser": {
          assertInitialize();
          final Map<String, String> args = call.arguments();
          final String userId = args.get("userId");
          args.remove("userId");

          if (userId == null) {
            fail("The userId is null.");
            break;
          }

          if (args.isEmpty()) {
            bucketeer.setUser(userId);
          } else {
            bucketeer.setUser(userId, args);
          }

          final SimpleSettableFuture<Boolean> future = new SimpleSettableFuture<>();
          bucketeer.fetchUserEvaluations(new Bucketeer.FetchUserEvaluationsCallbackAdapter() {
            @Override
            public void onError(BucketeerException e) {
              future.set(false);
            }

            @Override
            public void onSuccess() {
              future.set(true);
            }
          });

          final boolean isSuccess = future.get();
          if (isSuccess) {
            success();
          }

          break;
        }
        case "getStringVariation": {
          assertInitialize();
          final Map<String, Object> args = call.arguments();
          final String featureId = safeCast(args.get("featureId"), String.class);
          final String defaultValue = safeCast(args.get("defaultValue"), String.class);
          final String response = bucketeer.getVariation(featureId, defaultValue);
          success(response);
          break;
        }
        case "getIntVariation": {
          assertInitialize();
          final Map<String, Object> args = call.arguments();
          final String featureId = safeCast(args.get("featureId"), String.class);
          final Integer defaultValue = safeCast(args.get("defaultValue"), Integer.class);
          final Integer response = bucketeer.getVariation(featureId, defaultValue);
          success(response);
          break;
        }
        case "getDoubleVariation": {
          assertInitialize();
          final Map<String, Object> args = call.arguments();
          final String featureId = safeCast(args.get("featureId"), String.class);
          final Double defaultValue = safeCast(args.get("defaultValue"), Double.class);
          final Double response = bucketeer.getVariation(featureId, defaultValue);
          success(response);
          break;
        }
        case "getBoolVariation": {
          assertInitialize();
          final Map<String, Object> args = call.arguments();
          final String featureId = safeCast(args.get("featureId"), String.class);
          final Boolean defaultValue = safeCast(args.get("defaultValue"), Boolean.class);
          final Boolean response = bucketeer.getVariation(featureId, defaultValue);
          success(response);
          break;
        }
        case "track": {
          assertInitialize();
          final Map<String, Object> args = call.arguments();
          final String goalId = safeCast(args.get("goalId"), String.class);
          final Double value = safeCast(args.get("value"), Double.class);
          bucketeer.track(goalId, value);
          success();
          break;
        }
        case "start":
          assertInitialize();
          bucketeer.start();
          success();
          break;
        case "stop":
          assertInitialize();
          bucketeer.stop();
          success();
          break;
        default:
          result.notImplemented();
          break;
      }
    } catch (BucketeerException | RuntimeException e) {
      fail(e.getMessage());
    }
  }

  <T> T safeCast(Object o, Class<T> clazz) {
    return clazz != null && clazz.isInstance(o) ? clazz.cast(o) : null;
  }

  void assertInitialize() throws BucketeerException.IllegalStateException {
    if (bucketeer == null) {
      throw new BucketeerException.IllegalStateException("Required call the initialize method.");
    }
  }

  void success() {
    success(null);
  }

  void success(@Nullable Object response) {
    Map<String, Object> map = new HashMap<>();
    map.put("status", true);
    map.put("response", response);
    if (result != null) result.success(map);
  }

  void fail(String message) {
    Map<String, Object> map = new HashMap<>();
    map.put("status", false);
    map.put("errorMessage", message);
    if (result != null) result.success(map);
  }
}

==> flutter_bucketeer-1.3.0.tar.gz: android/src/main/java/jp/bucketeer/plugin/BucketeerPlugin.java <==
package jp.bucketeer.plugin;

import android.content.Context;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import jp.bucketeer.sdk.Bucketeer;
import jp.bucketeer.sdk.Evaluation;
import jp.bucketeer.sdk.User;
import jp.bucketeer.sdk.BucketeerConfig;
import jp.bucketeer.sdk.BucketeerException;

import java.util.HashMap;
import java.util.Map;

/**
 * BucketeerPlugin
 */
public class BucketeerPlugin implements MethodCallHandler, FlutterPlugin {
  private Context applicationContext;
  private MethodChannel methodChannel;
  private Bucketeer bucketeer;
  private Result result;

  /**
   * Plugin registration.
   */
  public static void registerWith(Registrar registrar) {
    final BucketeerPlugin instance = new BucketeerPlugin();
    instance.onAttachedToEngine(registrar.context(), registrar.messenger());
  }

  @Override
  public void onAttachedToEngine(FlutterPluginBinding binding) {
    onAttachedToEngine(binding.getApplicationContext(), binding.getBinaryMessenger());
  }

  private void onAttachedToEngine(Context applicationContext, BinaryMessenger messenger) {
    this.applicationContext = applicationContext;
    methodChannel = new MethodChannel(messenger, "jp.bucketeer.plugin/flutter");
    methodChannel.setMethodCallHandler(this);
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    applicationContext = null;
    methodChannel.setMethodCallHandler(null);
    methodChannel = null;
  }

  @Override
  public void onMethodCall(final MethodCall call, @NonNull final Result result) {
    this.result = result;
    try {
      switch (call.method) {
        case "initialize": {
          final BucketeerConfig config = new BucketeerConfig.Builder()
            .logSendingIntervalMillis(safeCast(call.argument("logSendingIntervalMillis"), Integer.class))
            .logSendingMaxBatchQueueCount(safeCast(call.argument("logSendingMaxBatchQueueCount"), Integer.class))
            .pollingEvaluationIntervalMillis(safeCast(call.argument("pollingEvaluationIntervalMillis"), Integer.class))
            .build();

          bucketeer = new Bucketeer.Builder(applicationContext)
            .config(config)
            .apiKey(safeCast(call.argument("apiKey"), String.class))
            .endpoint(safeCast(call.argument("endpoint"), String.class))
            .featureTag(safeCast(call.argument("featureTag"), String.class))
            .logcatLogging(safeCast(call.argument("debugging"), Boolean.class))
            .build();
          success();
          break;
        }
        case "setUser": {
          assertInitialize();
          final Map<String, String> args = call.arguments();
          final String userId = args.get("userId");
          args.remove("userId");

          if (userId == null) {
            fail("The userId is null.");
            break;
          }

          if (args.isEmpty()) {
            bucketeer.setUser(userId);
          } else {
            bucketeer.setUser(userId, args);
          }

          bucketeer.fetchUserEvaluations(new Bucketeer.FetchUserEvaluationsCallback() {
            @Override
            public void onError(@NonNull BucketeerException e) {
              fail("Failed to fetch the user.");
            }

            @Override
            public void onSuccess() {
              success();
            }
          });
          break;
        }
        case "getUser": {
          assertInitialize();
          final User user = bucketeer.getUser();
          if (user == null) {
            fail("Failed to fetch the user.");
          } else {
            Map<String, Object> map = new HashMap<>();
            map.put("id", user.getId());
            map.put("data", user.getData());
            success(map);
          }
          break;
        }
        case "getEvaluation": {
          assertInitialize();
          final Map<String, Object> args = call.arguments();
          final String featureId = safeCast(args.get("featureId"), String.class);

          final Evaluation evaluation = bucketeer.getEvaluation(featureId);
          if (evaluation == null) {
            fail("Failed to fetch the evaluation.");
          } else {
            Map<String, Object> map = new HashMap<>();
            map.put("id", evaluation.getId());
            map.put("featureId", evaluation.getFeatureId());
            map.put("featureVersion", evaluation.getFeatureVersion());
            map.put("userId", evaluation.getUserId());
            map.put("variationId", evaluation.getVariationId());
            map.put("variationValue", evaluation.getVariationValue());
            map.put("reason", evaluation.getReason());
            success(map);
          }
          break;
        }
        case "getStringVariation": {
          assertInitialize();
          final Map<String, Object> args = call.arguments();
          final String featureId = safeCast(args.get("featureId"), String.class);
          final String defaultValue = safeCast(args.get("defaultValue"), String.class);
          final String response = bucketeer.getVariation(featureId, defaultValue);
          success(response);
          break;
        }
        case "getIntVariation": {
          assertInitialize();
          final Map<String, Object> args = call.arguments();
          final String featureId = safeCast(args.get("featureId"), String.class);
          final Integer defaultValue = safeCast(args.get("defaultValue"), Integer.class);
          final Integer response = bucketeer.getVariation(featureId, defaultValue);
          success(response);
          break;
        }
        case "getDoubleVariation": {
          assertInitialize();
          final Map<String, Object> args = call.arguments();
          final String featureId = safeCast(args.get("featureId"), String.class);
          final Double defaultValue = safeCast(args.get("defaultValue"), Double.class);
          final Double response = bucketeer.getVariation(featureId, defaultValue);
          success(response);
          break;
        }
        case "getBoolVariation": {
          assertInitialize();
          final Map<String, Object> args = call.arguments();
          final String featureId = safeCast(args.get("featureId"), String.class);
          final Boolean defaultValue = safeCast(args.get("defaultValue"), Boolean.class);
          final Boolean response = bucketeer.getVariation(featureId, defaultValue);
          success(response);
          break;
        }
        case "track": {
          assertInitialize();
          final Map<String, Object> args = call.arguments();
          final String goalId = safeCast(args.get("goalId"), String.class);
          final Double value = safeCast(args.get("value"), Double.class);
          bucketeer.track(goalId, value);
          success();
          break;
        }
        case "start":
          assertInitialize();
          bucketeer.start();
          success();
          break;
        case "stop":
          assertInitialize();
          bucketeer.stop();
          success();
          break;
        default:
          result.notImplemented();
          break;
      }
    } catch (BucketeerException | RuntimeException e) {
      fail(e.getMessage());
    }
  }

  <T> T safeCast(Object o, Class<T> clazz) {
    return clazz != null && clazz.isInstance(o) ? clazz.cast(o) : null;
  }

  void assertInitialize() throws BucketeerException.IllegalStateException {
    if (bucketeer == null) {
      throw new BucketeerException.IllegalStateException("Required call the initialize method.");
    }
  }

  void success() {
    success(null);
  }

  void success(@Nullable Object response) {
    Map<String, Object> map = new HashMap<>();
    map.put("status", true);
    map.put("response", response);
    if (result != null) result.success(map);
  }

  void fail(String message) {
    Map<String, Object> map = new HashMap<>();
    map.put("status", false);
    map.put("errorMessage", message);
    if (result != null) result.success(map);
  }
}
